@@ -388,6 +388,12 @@ bundle:my_bundle  # items in this bundle
         type=str,
         help=_("create DIRECTORY and fill it with rendered file previews"),
     )
+    parser_items.add_argument(
+        "--attrs",
+        action='store_true',
+        dest='show_attrs',
+        help=_("show internal item attributes"),
+    )
     parser_items.add_argument(
         "--repr",
         action='store_true',
@@ -905,6 +911,13 @@ bundle:my_bundle  # items in this bundle
         dest='orphaned_bundles',
         help=_("check for bundles not assigned to any node"),
     )
+    parser_test.add_argument(
+        "-p",
+        "--reactor-provides",
+        action='store_true',
+        dest='reactor_provides',
+        help=_("check for reactors returning keys other than what they declared with @metadata_reactor.provides()"),
+    )
     parser_test.add_argument(
         "-q",
         "--quiet",
