@@ -20,15 +20,15 @@ from bundlewrap.operations import run_local
 BUILTIN_ITEM_ATTRIBUTES = {
     'cascade_skip': None,
     'comment': None,
-    'needed_by': [],
-    'needs': [],
-    'preceded_by': [],
-    'precedes': [],
+    'needed_by': set(),
+    'needs': set(),
+    'preceded_by': set(),
+    'precedes': set(),
     'error_on_missing_fault': False,
-    'tags': [],
+    'tags': set(),
     'triggered': False,
-    'triggered_by': [],
-    'triggers': [],
+    'triggered_by': set(),
+    'triggers': set(),
     'unless': "",
     'when_creating': {},
 }
@@ -83,7 +83,7 @@ def make_normalize(attribute_default):
     This is to ensure you can pass filter() results and such in place of
     lists and have them converted to the proper type automatically.
     """
-    if type(attribute_default) in (list, dict):
+    if type(attribute_default) in (dict, list, set, tuple):
         return type(attribute_default)
     else:
         return copy
@@ -137,13 +137,12 @@ class Item:
         bundle,
         name,
         attributes,
-        has_been_triggered=False,
         skip_validation=False,
         skip_name_validation=False,
     ):
         self.attributes = {}
         self.bundle = bundle
-        self.has_been_triggered = has_been_triggered
+        self.has_been_triggered = False
         self.item_dir = join(bundle.bundle_dir, self.BUNDLE_ATTRIBUTE_NAME)
         self.item_data_dir = join(bundle.bundle_data_dir, self.BUNDLE_ATTRIBUTE_NAME)
         self.name = name
@@ -151,7 +150,7 @@ class Item:
         self.when_creating = {}
         self._command_results = []
         self._faults_missing_for_attributes = set()
-        self._precedes_items = []
+        self._precedes_items = set()
 
         if not skip_validation:
             if not skip_name_validation:
@@ -211,6 +210,12 @@ class Item:
                 item=self.id,
             ))
 
+    def __eq__(self, other):
+        return self.id == other.id
+
+    def __hash__(self):
+        return hash(self.id)
+
     def __lt__(self, other):
         return self.id < other.id
 
@@ -246,22 +251,6 @@ class Item:
                 node=self.node.name,
             ))
 
-    def _check_redundant_dependencies(self):
-        """
-        Alerts the user if they have defined a redundant dependency
-        (such as settings 'needs' on a triggered item pointing to the
-        triggering item).
-        """
-        for dep in self._deps:
-            if self._deps.count(dep) > 1:
-                raise ItemDependencyError(_(
-                    "redundant dependency of {item1} in bundle '{bundle}' on {item2}"
-                ).format(
-                    bundle=self.bundle.name,
-                    item1=self.id,
-                    item2=dep,
-                ))
-
     @cached_property
     def cached_cdict(self):
         if self._faults_missing_for_attributes:
@@ -327,10 +316,6 @@ class Item:
                 return True
         return not self.cached_status.correct
 
-    def _prepare_deps(self, items):
-        # merge automatic and user-defined deps
-        self._deps = list(self.needs) + list(self.get_auto_deps(items))
-
     def _raise_for_faults(self):
         raise FaultUnavailable(_(
             "{item} on {node} is missing faults "
