@@ -10,10 +10,7 @@ from tomlkit import dumps as toml_dump, parse as toml_parse
 from . import operations
 from .bundle import Bundle
 from .concurrency import WorkerPool
-from .deps import (
-    DummyItem,
-    find_item,
-)
+from .deps import find_item
 from .exceptions import (
     GracefulApplyException,
     ItemDependencyLoop,
@@ -28,13 +25,12 @@ from .itemqueue import ItemQueue
 from .items import Item
 from .lock import NodeLock
 from .metadata import hash_metadata
-from .utils import cached_property, error_context, get_file_contents, names, NO_DEFAULT
+from .utils import cached_property, error_context, get_file_contents, names
 from .utils.dicts import (
     dict_to_toml,
     hash_statedict,
     set_key_at_path,
     validate_dict,
-    value_at_key_path,
     COLLECTION_OF_STRINGS,
 )
 from .utils.text import (
@@ -90,6 +86,9 @@ class ApplyResult:
         self.start = None
         self.end = None
 
+    def __lt__(self, other):
+        return self.node_name < other.node_name
+
     @property
     def duration(self):
         return self.end - self.start
@@ -152,9 +151,9 @@ def apply_items(
     workers=1,
     interactive=False,
 ):
-    item_queue = ItemQueue(node.items, node.os, node.os_version)
-    # the item queue might contain new generated items (canned actions,
-    # dummy items); adjust progress total accordingly
+    item_queue = ItemQueue(node)
+    # the item queue might contain new generated items (canned actions)
+    # adjust progress total accordingly
     extra_items = len(item_queue.all_items) - len(node.items)
     io.progress_increase_total(increment=extra_items)
 
@@ -223,8 +222,7 @@ def apply_items(
 
         handle_apply_result(node, item, status_code, interactive, details=details)
         io.progress_advance()
-        if not isinstance(item, DummyItem):
-            results.append((item.id, status_code, duration))
+        results.append((item.id, status_code, duration))
 
     worker_pool = WorkerPool(
         tasks_available,
@@ -676,26 +674,11 @@ class Node:
 
     @property
     def metadata(self):
-        return self.repo._metadata_for_node(self.name)
+        return self.repo._metadata_proxy_for_node(self.name)
 
-    @property
-    def metadata_blame(self):
-        return self.repo._metadata_for_node(self.name, blame=True)
-
-    @property
-    def _metadata_stack(self):
-        return self.repo._metadata_for_node(self.name, stack=True)
-
-    def metadata_get(self, path, default=NO_DEFAULT):
-        if not isinstance(path, (tuple, list)):
-            path = path.split("/")
-        try:
-            return value_at_key_path(self.metadata, path)
-        except KeyError:
-            if default != NO_DEFAULT:
-                return default
-            else:
-                raise
+    def metadata_get(self, *args, **kwargs):
+        # TODO remove in 5.0
+        return self.metadata.get(*args, _backwards_compatibility_default=False, **kwargs)
 
     def metadata_hash(self):
         return hash_metadata(self.metadata)
@@ -868,7 +851,7 @@ def verify_items(node, show_all=False, workers=1):
     for item in node.items:
         if not item.triggered:
             items.append(item)
-        elif not isinstance(item, DummyItem):
+        else:
             io.progress_advance()
 
     try:
